@@ -22,6 +22,9 @@ from fnmatch import fnmatch
 from setuptools import Command
 
 from base import yes_no_input
+from base import safe_input
+from base import display
+
 from packet import get_version
 from packet import raise_version
 from packet import check_tests
@@ -54,7 +57,7 @@ class release(Command):
     def finalize_options(self):
         """finalize options"""
         if self.auto and not self.version:
-            print 'You must specify a version in auto mode'
+            display('You must specify a version in auto mode')
             sys.argv.append('-h')
             __import__('setup')
             sys.exit(-1)
@@ -74,51 +77,47 @@ def make_package_release(auto=False,
                          new_version=''):
     """release process"""
     version = get_version()
-    print 'This package is version %s' % version
+    display('This package is version %s' % version)
 
     # tests (not called in auto mode)
     if not auto:
         if not testing:
             testing = yes_no_input(('Do you want to run tests before '
-                                 'releasing ?'), default='y')
+                                    'releasing ?'), default='n')
         if testing:
             check_tests()
 
     # releasing
     if not auto:
         if not release:
-            release = yes_no_input('Do you want to create the release ?')
+            release = yes_no_input(('Do you want to create the release ? '
+                                    'If no, you will just be able to deploy again ' 
+                                    'the current release'))
     else:
         release = True
 
     if release:
         if not auto:
             if not new_version:
-                new_version = raw_input('Enter a version : ')
-            raise_version(new_version)
+                new_version = safe_input('Enter a version',
+                                         version)
+            if version != new_version:
+                raise_version(new_version)
         else:
             if not new_version:
                 new_version = str(float(version)+.1)
-            print 'Raising the version...'
+            display('Raising the version...')
             raise_version(new_version)
 
-        print 'Commiting changes...'
+        display('Commiting changes...')
         increment_changes()
-        print 'Creating branches...'
+        display('Creating branches...')
         create_branches()
     else:
         new_version = version
 
-    if not auto:
-        if not upload:
-            upload = yes_no_input(('Do you want to upload the package '
-                                   'to various package servers ?'))
-        if upload:
-            pypi_upload()
-    else:
-        pypi_upload(interactive=False)
-
-    print '%s released' % new_version
+    pypi_upload(interactive=False)
+    display('%s released to private PyPI' % new_version)
 
 class build_mo(Command):
     """Msgfmt"""
@@ -161,7 +160,7 @@ class build_mo(Command):
             for domain_file in os.listdir(lc_path):
                 if domain_file.endswith('.po'):
                     file_path = os.path.join(lc_path, domain_file)
-                    print "Building .mo for", file_path
+                    display("Building .mo for %s" % file_path)
                     mo_file = os.path.join(lc_path, '%s.mo' % domain_file[:-3])
                     mo_content = Msgfmt(file_path, name=file_path).get()
                     mo = open(mo_file, 'wb')
