@@ -18,8 +18,10 @@ import ConfigParser
 import os
 import re
 import sys
+from glob import glob
 from tempfile import mkdtemp
-import base
+
+from iw.releaser import base
 
 join = os.path.join
 
@@ -86,7 +88,9 @@ def check_python(valid_version=(2, 4)):
     version = sys.version_info[0:len(valid_version)]
     if version != valid_version:
         version = '.'.join([str(step) for step in version])
-        raise base.ReleaseError('You must run python%s' % version)
+        valid_version = '.'.join([str(step) for step in valid_version])
+        msg = 'Found Python %s, need %s' (version, valid_version)
+        raise base.ReleaseError(msg)
     else:
         return '.'.join([str(v) for v in version])
 
@@ -135,30 +139,38 @@ def diff_releases(old=None, new=None, result=None):
 
     # now writing the diff tarball
     _log('Writing archive')
-    diff_tarball = base.TarFile.open(result, 'w:gz')
-    try:
-        for root, dirs, filenames in os.walk(tmp):
-            for filename in filenames:
-                path = join(root, filename)
-                arcname = path.replace(tmp, '')
-                diff_tarball.add(path, arcname, False)
-    finally:
-        diff_tarball.close()
+    archive_contents(result, tmp)
     _log('Diff done.')
 
 def archive_contents(archive, location, previous=None):
     """generates the tarball"""
     location = os.path.realpath(location)
+    # we want a relative storage
+    old_dir = os.curdir    
+    os.chdir(location)
     dirname, name = os.path.split(location)
     tar = base.TarFile.open(join(dirname, archive), 'w:gz')
     try:
-        for root, dirs, filenames in os.walk(location):
+        for root, dirs, filenames in os.walk('.'):
+            if '.svn' in root.split(os.path.sep):
+                continue
+            # archiving empty dirs
+            for dir_ in dirs:   
+                if '.svn' in dir_.split(os.path.sep):
+                    continue
+                fullpath = os.path.join(root, dir_)
+                if os.listdir(fullpath) == []:
+                    arcname = fullpath.replace(location, '.')
+                    tar.add(fullpath, arcname, False) 
             for filename in filenames:
+                if filename in ('.installed.cfg', '.Python'):
+                    continue
                 path = join(root, filename)
-                arcname = path.replace(location, name)
+                arcname = path.replace(location, '.')
                 tar.add(path, arcname, False)
     finally:
         tar.close()
+        os.chdir(old_dir)
 
 def set_option(filename, section, option, value):
     """Setting option."""
@@ -181,12 +193,13 @@ def get_option(filename, section, option):
 
 def _python():
     """returns python bin"""
-    possible_locations = (join('bin', 'python'),
-                          join('bin', 'python2.4'),
-                          join('Scripts', 'python'))
+    
+    possible_locations = (join('bin', 'python*'),
+                          join('Scripts', 'python*'))
     for location in possible_locations:
-        if os.path.exists(location):
-            return location
+        for found in glob(location):
+            if os.path.exists(found):
+                return found
     return 'python'
 
 def deploy_release(path=None, target=None, archiving='full'):
@@ -196,21 +209,24 @@ def deploy_release(path=None, target=None, archiving='full'):
 
     if path is None:
         if len(sys.argv) < 2:
-            print 'usage : project_deploy http://to/your/buildout/config.cfg'
+            print 'usage : project_deploy [http://to/your/buildout/]config.cfg'
             sys.exit(1)
         path = sys.argv[1]
-
     url, filename = parse_url(path)
-    folder = url.split('/')[-1]
-    release_name = '%s-%s' % (folder, filename.split('.')[0])
-    if not target:
-        target = release_name
+    if url == '':   # local file
+        target, filename = os.path.split(path)
+        release_name = filename.split('.')[0]  
+    else:
+        folder = url.split('/')[-1]
+        release_name = '%s-%s' % (folder, filename.split('.')[0])
+        if not target:
+            target = release_name
 
-    if os.path.isfile(path) or os.path.isdir(path):
-        target = url
+        if os.path.isfile(path) or os.path.isdir(path):
+            target = url
 
-    if not os.path.isdir(target):
-        os.mkdir(target)
+        if not os.path.isdir(target):
+            os.mkdir(target)
 
     root = os.path.realpath(target)
     os.chdir(root)
@@ -219,8 +235,6 @@ def deploy_release(path=None, target=None, archiving='full'):
     if not os.path.isfile(path) and not os.path.isdir(path):
         # let's get the buildout
         print base.system('svn co %s .' % url)
-    else:
-        target = url
 
     print 'Using local directory %s with %s' % (target, filename)
 
@@ -243,12 +257,13 @@ def deploy_release(path=None, target=None, archiving='full'):
     binary = join('bin', 'buildout')
     buildout = 'buildout.cfg'
 
+    # XXX need to parse extended as well
     # see if download-cache was present
-    try:
-        cache = get_option(filename, 'buildout', 'download-cache')
-    except ConfigParser.NoOptionError:
-        raise base.ReleaseError(("You need to add 'download-cache = downloads'"
-                                 "' in the [buildout] section"))
+    #try:
+    #    cache = get_option(filename, 'buildout', 'download-cache')
+    #except ConfigParser.NoOptionError:
+    #    raise base.ReleaseError(("You need to add 'download-cache = downloads'"
+    #                             "' in the [buildout] section"))
 
     print 'Checking binary.'
     buildout_cmd = '%s -c %s -v' % (binary, filename)
@@ -264,21 +279,27 @@ def deploy_release(path=None, target=None, archiving='full'):
     print '%s ok.' % binary
 
     # archiving process: changes buildout.cfg and create a tarball
-    if filename != 'buildout.cfg':
-        set_option(buildout, 'buildout', 'extends', filename)
+    old_content = open('buildout.cfg').read()
+    try:
+        if filename != 'buildout.cfg':
+            set_option(buildout, 'buildout', 'extends', filename)
 
-    set_option(buildout, 'buildout', 'install-from-cache',
-               'true')
-    set_option(buildout, 'buildout', 'offline', 'true')
+        set_option(buildout, 'buildout', 'install-from-cache',
+                   'true')
+        set_option(buildout, 'buildout', 'offline', 'true')
 
-    # archiving:
-    #  - a full archive
-    #  - an diffed archived
-    print 'Archiving %s.' % target
-    if archiving == 'none':
-        return
-    archive = 'release-%s-%s.tgz' % (os.path.split(target)[-1],
-                                     filename.split('.')[0])
-    archive_contents(archive, '.')
-    print '%s ok.' % archive
+        # archiving:
+        #  - a full archive
+        #  - an diffed archived
+        print 'Archiving %s.' % target
+        if archiving == 'none':
+            return
+        archive = 'release-%s.tgz' % release_name
+        archive_contents(archive, '.')
+        print '%s ok.' % archive
+    finally:
+        # setting back the original buildout.cfg file    
+        f = open('buildout.cfg', 'w')
+        f.write(old_content)
+        f.close()
 
